@@ -8,20 +8,19 @@ object Protocol {
   val DOUBLE =  2
   val BOOLEAN = 3
   val STRING =  4
+  val BYTE =    5
 
   // Data Structures
   val UNSUPPORTED_STRUCTURE = 10
   val NULLTYPE  = 11
   val REFERENCE = 12
-  val ATOMIC    = 13
+  val SCALAR    = 13
   val VECTOR    = 14
   val MATRIX    = 15
 
   // Commands
   val EXIT          = 100
-  val RESET         = 101
-  val GC            = 102
-  val DEBUG         = 103
+  val FREE          = 103
   val EVAL          = 104
   val SET           = 105
   val SET_SINGLE    = 106
@@ -31,6 +30,8 @@ object Protocol {
   val DEF           = 110
   val INVOKE        = 111
   val SCALAP        = 112
+  val EVALNAKED     = 113
+  val SHUTDOWN      = 114
 
   // Result
   val OK = 1000
@@ -38,7 +39,7 @@ object Protocol {
   val UNDEFINED_IDENTIFIER = 1002
 
   // Misc.
-  val CURRENT_SUPPORTED_SCALA_VERSION = "2.11.8"
+  val CURRENT_SUPPORTED_SCALA_VERSION = "2.12.2"
 
 }
 
