@@ -3,16 +3,15 @@ INTEGER <- 1L
 DOUBLE <-  2L
 BOOLEAN <- 3L
 STRING <-  4L
+BYTE <-    5L
 UNSUPPORTED_STRUCTURE <- 10L
 NULLTYPE  <- 11L
 REFERENCE <- 12L
-ATOMIC    <- 13L
+SCALAR    <- 13L
 VECTOR    <- 14L
 MATRIX    <- 15L
 EXIT          <- 100L
-RESET         <- 101L
-GC            <- 102L
-VACANT_103    <- 103L
+FREE          <- 103L
 EVAL          <- 104L
 SET           <- 105L
 SET_SINGLE    <- 106L
@@ -27,4 +26,4 @@ SHUTDOWN      <- 114L
 OK <- 1000L
 ERROR <- 1001L
 UNDEFINED_IDENTIFIER <- 1002L
-CURRENT_SUPPORTED_SCALA_VERSION <- "2.12.0"
+CURRENT_SUPPORTED_SCALA_VERSION <- "2.12.2"
